Ext.setup({
    icon: 'icon.png',
	tabletStartupScreen: 'tablet_startup.png',
	phoneStartupScreen: 'phone_startup.png',
	glossOnIcon: false,
	onReady: function() {

		Ext.define('SimpleFormView', {

			extend: 'Ext.form.FormPanel',
			xtype: 'simpleformview',

			config: {
				fullscreen: true,
				title: 'Form...',
				scroll: 'vertical',
				items: [{
					xtype: 'fieldset',
					title: '',
					itemId: 'simpleForm',
					instructions: '',
					defaults: {
						xtype: 'textfield',
						readOnly: true,
						labelWidth: '40%'
					},
					items: [{
						xtype: 'textfield',
						name: 'CUSNO',
						label: 'Customer #'
					}, {
						name: 'CNAME',
						label: 'Name'
					}, {
						name: 'CADDR1',
						label: 'Address 1'
					}, {
						name: 'CADDR2',
						label: 'Address 2'
					}, {
						name: 'CCITY',
						label: 'City'
					}, {
						name: 'CSTATE',
						label: 'State'
					}, {
						name: 'CCOUNTRY',
						label: 'Country'
					}, {
						name: 'CZIP',
						label: 'Zipcode'
					}, {
						xtype: 'map',
						height: 200,
						itemId: 'mapholder',
						useCurrentLocation: true
					}]
				}]
			}
		});

		Ext.define('CustomerModel', {
			extend: 'Ext.data.Model',
			config: {
				fields: [{
					name: 'CUSNO',
					type: 'int'
				}, {
					name: 'CNAME',
					type: 'string'
				}]
			}
		});

		var customerStore = new Ext.data.Store({
			model: 'CustomerModel',
			proxy: {
				type: 'ajax',
				url: 'vvcall.pgm',
				extraParams: {
					pgm: 'CUSTMAPR',
					action: 'getCustLst'
				},
				reader: {
					type: 'json',
					rootProperty: 'DEMOCMAST'
				}
			},
			autoLoad: true
		});

		var tmpl = new Ext.Template(
        '<table>', 
            '<tr>', 
                '<td align="right" width="50">', 
                    '{CUSNO}', 
                    '</td>', 
                    '<td width="10">', 
                    '</td>', 
                    '<td>', 
                    '{CNAME}', 
                '</td>', 
            '</tr>', 
        '</table>');

		Ext.define('LoadAllView', {
			extend: 'Ext.Panel',
			xtype: 'loadallview',
			config: {
				title: 'Customer List',
				layout: 'fit',
				fullscreen: true,

				items: [{
					xtype: 'list',
					scroll: 'vertical',
					itemTpl: tmpl,
					store: customerStore,
					listeners: {
						itemtap: showMapPanel
					}
				}]
			}
		});

		Ext.define('MainNavView', {
			extend: 'Ext.navigation.View',
			xtype: 'mainpanel',
			config: {
				items: [{
					xtype: 'loadallview'
				}]
			}

		});

		Ext.Viewport.add({
			xtype: 'mainpanel'
		});

		function showMapPanel(list, index, item, record) {

			Ext.Viewport.mask({
				xtype: 'loadmask',
				message: 'Loading ' + record.data.CNAME
			});

			var simple = Ext.widget('simpleformview');

			simple.config.title = record.data.CNAME;

			var main = Ext.Viewport.down('.mainpanel');

			main.push(simple);

			Ext.Ajax.request({
				url: 'vvcall.pgm',
				params: {
					pgm: 'CUSTMAPR',
					action: 'getCustRcd',
					cusno: record.data.CUSNO
				},
				scope: this,
				success: function(response) {
					var data = Ext.decode(response.responseText);
					if (data.SUCCESS == '1') {
						simple.setValues(data);

						var geocoder = new google.maps.Geocoder();

						Ext.Viewport.unmask();

						geocoder.geocode({
							'address': data.CZIP
						}, function(results, status) {

							if (status == google.maps.GeocoderStatus.OK) {
								var latitude = results[0].geometry.location.lat();
								var longitude = results[0].geometry.location.lng();

								var map = simple.down('#mapholder');

								map.setUseCurrentLocation(false);

								map.setMapCenter({
									latitude: latitude,
									longitude: longitude
								});							
							}
						});

					} else {
						Ext.Msg.alert('Error ', data.MSGTEXT + ': ' + data.CNAME, function() {
							this.getSimpleFormView().reset();
						}, this);
					}
				}
			});
		}

	}

});
